Skip to content
KitploitKITPLOIT
OutilsExploitsBlog
Log in
Soumettre
OutilsExploitsBlog
Soumettre

Outils de Hacking, PenTest et Cybersécurité pour votre Arsenal de Sécurité !

Kitploit est un répertoire d'outils de hacking, de cybersécurité et de pentesting. Découvrez les dernières mises à jour des projets pour trouver des vulnérabilités, analyser des systèmes, automatiser les tests et renforcer votre sécurité.

··Flux·Contact·Confidentialité·© 2026 Kitploit

Répertoire d'outils

Catégories

Voir toutes les catégories
Loading categories
tmpmail — Un email temporaire directement depuis votre terminal écrit en POSIX sh | Kitploit
Outils/GitHubGitHub/sdushantha/tmpmail
Utilitaires GénérauxProtection de la Vie PrivéeSécurité des Emails
GitHubsdushantha/tmpmail

tmpmail

Un email temporaire directement depuis votre terminal écrit en POSIX sh

Voir le dépôt
4.2k16420il y a 4 ansVérifié par Kitploit

Populaires

Voir tout →

Découvrez les outils les plus utilisés par notre communauté.

Explorer tous les outils

Parcourez notre collection d'outils

Voir tous les outils →
Partager

Un email temporaire directement depuis votre terminal écrit en POSIX sh


tmpmail est un utilitaire en ligne de commande écrit en POSIX sh qui vous permet de créer une adresse email temporaire et de recevoir des emails sur cette adresse. Il utilise l'API de 1secmail pour recevoir les emails.

Par défaut, w3m est utilisé pour afficher les emails HTML dans le terminal. Mais si vous préférez un autre navigateur web textuel ou souhaitez plutôt voir l'email dans un navigateur web graphique comme Firefox, utilisez simplement l'argument --browser suivi de la commande nécessaire pour lancer le navigateur web de votre choix.




Dépendances

  • w3m
  • curl
  • jq
  • xclip

Installation

Installer localement

# Téléchargez le fichier tmpmail et rendez-le exécutable
$ curl -L "https://raw.githubusercontent.com/sdushantha/tmpmail/master/tmpmail" > tmpmail && chmod +x tmpmail

# Déplacez-le ensuite dans un dossier de votre $PATH. Exemple :
$ mv tmpmail ~/bin/

AUR

tmpmail est disponible sur l'AUR, actuellement maintenu par Benjamin Bädorf

$ yay -S tmpmail-git

Pacstall (Debian/Ubuntu)

tmpmail est disponible dans le dépôt pacstall-programs, actuellement maintenu par wizard-28

$ pacstall -I tmpmail-bin

Nixpkgs

tmpmail est également disponible dans la collection de paquets nix (uniquement unstable pour le moment), maintenue par legendofmiracles

Ajoutez-le à vos paquets système, installez-le avec nix-env ou essayez-le dans un nix-shell éphémère avec nix-shell -p tmpmail.

Docker

prérequis :

  • docker
  • clonez ce dépôt
$ docker build -t mail .; # Dockerfile disponible dans le code source
$ docker run -it mail;

Utilisation

$ tmpmail --help
tmpmail
tmpmail -h | --version
tmpmail -g [ADRESSE]
tmpmail [-t | -b NAVIGATEUR] -r | ID

Lorsqu'il est appelé sans option ni argument, tmpmail liste les messages dans
la boîte de réception et leurs ID numériques.  Lorsqu'il est appelé avec un argument, tmpmail
affiche le message email avec l'ID spécifié.

-b, --browser NAVIGATEUR
        Spécifie le NAVIGATEUR utilisé pour afficher le HTML de
        l'email (par défaut : w3m)
    --clipboard-cmd COMMANDE
        Spécifie la COMMANDE à utiliser pour copier l'adresse email dans votre
        presse-papier (par défaut : xclip -selection c)
-c, --copy
        Copie l'adresse email dans votre presse-papier
-d, --domains
        Affiche la liste des domaines disponibles
-g, --generate [ADRESSE]
        Génère une nouvelle adresse email, soit l'ADRESSE spécifiée, soit
        en crée une aléatoirement
-h, --help
        Affiche l'aide
-r, --recent
        Affiche le message email le plus récent
-t, --text
        Affiche l'email en texte brut, où toutes les balises HTML sont supprimées.
        Sans cette option, le HTML est utilisé.
--version
        Affiche la version

Exemples

Créer un email aléatoire

$ tmpmail --generate
[email protected]

Créer un email personnalisé

$ tmpmail --generate monemailpersonnalisé@1secmail.com
monemailpersonnalisé@1secmail.com

Afficher la boîte de réception

$ tmpmail
[ Boîte de réception pour [email protected] ]

83414443   [email protected]   Test Email

Afficher l'email

$ tmpmail 83414443

Afficher l'email le plus récent

$ tmpmail -r

Afficher les emails en texte pur

$ tmpmail -t 83414443
To: [email protected]
From: [email protected]
Subject: Test Email

Hello World

[Pièces jointes]
https://is.gd/aBCdEf [apple.jpg]
https://is.gd/AbCDeF [ball.jpg]

Crédits

Ce script est fortement inspiré du script 1secmail de Mitch Weaver.

Télécharger l’outil